==> sapdb-source-7.3.00.48.tgz: V73_00_48/SAPDB_ORG/sys/src/co/vco91.cpp <==
/* @lastChanged: "1998-09-21  11:46"
 * @filename:    vco91.cpp
 * @purpose:     "Implementation of hidden OmsHandle Functions"
 * @release:     7.1.0.0
 * @see:         ""
 *
 * @copyright:   "Copyright by SAP AG, 1998"


    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end

 */

/*===========================================================================*
 *  INCLUDES                                                                 *
 *===========================================================================*/

#define AFX_EXT_CLASS
#include "geo00.h"
#include "gco00.h"
#include "gco10.h"
#include "hco91.h"

/*===========================================================================*
 *  DEFINES                                                                  *
 *===========================================================================*/

#ifdef NO_INLINES
# define _INLINE
#else
# define _INLINE	inline
#endif



/*===========================================================================*
 *  MACROS                                                                   *
 *===========================================================================*/



/*===========================================================================*
 *  LOCAL CLASSES, STRUCTURES, TYPES, UNIONS ...                             *
 *===========================================================================*/



/*===========================================================================*
 *  EXTERNAL VARIABLES                                                       *
 *===========================================================================*/



/*===========================================================================*
 *  GLOBAL VARIABLES                                                         *
 *===========================================================================*/



/*===========================================================================*
 *  LOCAL VARIABLES                                                          *
 *===========================================================================*/



/*===========================================================================*
 *  LOCAL FUNCTIONS (PROTOTYPES)                                             *
 *===========================================================================*/



/*===========================================================================*
 *  GLOBAL FUNCTIONS (CODE)                                                  *
 *===========================================================================*/

HRESULT co91AttachDefaultContext (OmsHandle& h) {
  return h.omsAttachDefaultContext ();
}

/*----------------------------------------------------------------------*/

HRESULT co91ReleaseDefaultContext (OmsHandle& h) {
  return h.omsReleaseDefaultContext ();
}

/*----------------------------------------------------------------------*/

void co91MonitorInfo (OmsHandle& h, tgg00_COMMonitorTransferBuf* lpMonInfo) {
  h.omsGetMonitorInfo (lpMonInfo);
}

/*----------------------------------------------------------------------*/

void co91RegisterMonitor (OmsHandle& h, void* pMon) {
  h.omsRegMonitor (pMon);
}

/*----------------------------------------------------------------------*/

void co91SetCurrMonitorMethod (OmsHandle& h, tgg00_COMMonitorInfo* p) {
  co10_SetCurrMonitorMethod(h, p);
}

/*----------------------------------------------------------------------*/

short co91OmsCommit (OmsHandle& h, bool doRelease) 
{
  return h.omsCommit(doRelease);
}

/*----------------------------------------------------------------------*/

void co91OmsRollback(OmsHandle& h, bool doRelease)
{
  h.omsRollback(doRelease);
}

/*----------------------------------------------------------------------*/

short co91OmsValidate(OmsHandle& h)
{
  try {
    h.omsValidate ();
  }
  catch (...) {
    return -9999;
  }
  
  return 0;
}

/*----------------------------------------------------------------------*/

void co91OmsCleanUp (OmsHandle& h) {
  h.omsCleanUpAfterCrash();
};

/*===========================================================================*
 *  LOCAL FUNCTIONS (CODE)                                                   *
 *===========================================================================*/



/*===========================================================================*
 *  END OF CODE                                                              *
 *===========================================================================*/

==> sapdb-source-7.4.03.32.tgz: V74_03_32/SAPDB_ORG/sys/src/co/vco91.cpp <==
/* @lastChanged: "1998-09-21  11:46"
 * @filename:    vco91.cpp
 * @purpose:     "Implementation of hidden OmsHandle Functions"
 * @release:     7.1.0.0
 * @see:         ""
 *
 * @copyright:   "Copyright by SAP AG, 1998"


    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end

 */

/*===========================================================================*
 *  INCLUDES                                                                 *
 *===========================================================================*/

#define AFX_EXT_CLASS
#include "geo00.h"
#include "gco00.h"
#include "gco10.h"
#include "hco91.h"

/*===========================================================================*
 *  DEFINES                                                                  *
 *===========================================================================*/

#ifdef NO_INLINES
# define _INLINE
#else
# define _INLINE	inline
#endif



/*===========================================================================*
 *  MACROS                                                                   *
 *===========================================================================*/



/*===========================================================================*
 *  LOCAL CLASSES, STRUCTURES, TYPES, UNIONS ...                             *
 *===========================================================================*/



/*===========================================================================*
 *  EXTERNAL VARIABLES                                                       *
 *===========================================================================*/



/*===========================================================================*
 *  GLOBAL VARIABLES                                                         *
 *===========================================================================*/



/*===========================================================================*
 *  LOCAL VARIABLES                                                          *
 *===========================================================================*/



/*===========================================================================*
 *  LOCAL FUNCTIONS (PROTOTYPES)                                             *
 *===========================================================================*/



/*===========================================================================*
 *  GLOBAL FUNCTIONS (CODE)                                                  *
 *===========================================================================*/

HRESULT co91AttachDefaultContext (OmsHandle& h) {
  return h.omsAttachDefaultContext ();
}

/*----------------------------------------------------------------------*/

HRESULT co91ReleaseDefaultContext (OmsHandle& h) {
  return h.omsReleaseDefaultContext ();
}

/*----------------------------------------------------------------------*/

void co91CurrMethodCallEpilog (OmsHandle& h, void* sql_handle, int runTime)     /* PTS 1120804 */
{
  co10_MethodCallEpilog (h, sql_handle, runTime);
}

/*----------------------------------------------------------------------*/

void co91MonitorInfo (OmsHandle& h, tgg00_COMMonitorTransferBuf* lpMonInfo) {
  h.omsGetMonitorInfo (lpMonInfo);
}

/*----------------------------------------------------------------------*/

void co91RegisterMonitor (OmsHandle& h, void* pMon) {
  h.omsRegMonitor (pMon);
}

/*----------------------------------------------------------------------*/

void co91SetCurrMonitorMethod (OmsHandle& h, tgg00_COMMonitorInfo* p) {
  co10_SetCurrMonitorMethod(h, p);
}

/*----------------------------------------------------------------------*/

short co91OmsCommit (OmsHandle& h, bool doRelease) 
{
  return h.omsCommit(doRelease);
}

/*----------------------------------------------------------------------*/

void co91OmsRollback(OmsHandle& h, bool doRelease)
{
  h.omsRollback(doRelease, false);
}

/*----------------------------------------------------------------------*/

short co91OmsValidate(OmsHandle& h)
{
  try {
    h.omsValidate ();
  }
  catch (...) {
    return -9999;
  }
  
  return 0;
}

/*----------------------------------------------------------------------*/

void co91OmsCleanUp (OmsHandle& h) {
  h.omsCleanUpAfterCrash();
};

/*----------------------------------------------------------------------*/

void co91TransEndEpilog (OmsHandle& h) // PTS1110315
{
  h.omsTransEndEpilog();
}

/*===========================================================================*
 *  LOCAL FUNCTIONS (CODE)                                                   *
 *===========================================================================*/



/*===========================================================================*
 *  END OF CODE                                                              *
 *===========================================================================*/
